import 'package:flutter/material.dart';
import 'package:flutter_yingyan_trace_demo/customWidgets/selected_box.dart';
import 'package:flutter_yingyan_trace_demo/general/themes.dart';

typedef TrackAnalysisBarCallback = Function(int index, bool selected);

class TrackAnalysisBar extends StatefulWidget {
  final TrackAnalysisBarCallback? callback;
  final VoidCallback? closeCallback;

  const TrackAnalysisBar({Key? key, this.callback, this.closeCallback}) : super(key: key);

  @override
  _TrackAnalysisBarState createState() => _TrackAnalysisBarState();
}

class _TrackAnalysisBarState extends State<TrackAnalysisBar> {
  List<bool> _trackBoxStatus = [false, false, false, false, false];

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.only(left: 5, right: 5),
      padding: EdgeInsets.all(10),
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.only(
            topLeft: Radius.circular(4.0),
            topRight: Radius.circular(4.0)),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                "轨迹分析",
                style: settingTitleStyle,
              ),
              GestureDetector(
                behavior: HitTestBehavior.opaque,
                child: Container(
                  padding: EdgeInsets.only(left: 50),
                  child: Image.asset("images/general/icon_close.png", width: 20, height: 20,),
                ),
                onTap: () {
                  if (widget.closeCallback != null) {
                    widget.closeCallback!();
                  }
                },
              ),
            ],
          ),
          Container(
            color: separateColor,
            height: 0.5,
            margin: EdgeInsets.only(top: 10, bottom: 10),
          ),
          Wrap(
            spacing: 10,
            runSpacing: 10,
            children: [
              SelectedBox(
                title: "超速",
                selected: _trackBoxStatus[0],
                onTap: () => _onTapSelectedBox(0),
              ),
              SelectedBox(
                title: "急刹车",
                selected: _trackBoxStatus[1],
                onTap: () => _onTapSelectedBox(1),
              ),
              SelectedBox(
                title: "急变速",
                selected: _trackBoxStatus[2],
                onTap: () => _onTapSelectedBox(2),
              ),
              SelectedBox(
                title: "急转弯",
                selected: _trackBoxStatus[3],
                onTap: () => _onTapSelectedBox(3),
              ),
              SelectedBox(
                title: "停留点",
                selected: _trackBoxStatus[4],
                onTap: () => _onTapSelectedBox(4),
              ),
            ],
          ),
        ],
      ),
    );
  }

  void _onTapSelectedBox(int idx) {
    setState(() {
      _trackBoxStatus[idx] = !_trackBoxStatus[idx];
    });

    if (widget.callback != null) {
      widget.callback!(idx, _trackBoxStatus[idx]);
    }
  }
}
