import 'package:flutter/material.dart';
import 'package:flutter_baidu_yingyan_trace/flutter_baidu_yingyan_trace.dart';
import 'package:flutter_yingyan_trace_demo/customWidgets/map_appbar.dart';
import 'package:flutter_yingyan_trace_demo/customWidgets/map_raised_button.dart';
import 'package:flutter_yingyan_trace_demo/customWidgets/selected_box.dart';
import 'package:flutter_yingyan_trace_demo/customWidgets/text_field.dart';
import 'package:flutter_yingyan_trace_demo/general/themes.dart';

/// 追踪设置页
class TraceSettingPage extends StatefulWidget {
  @override
  _TraceSettingPageState createState() => _TraceSettingPageState();
}

class _TraceSettingPageState extends State<TraceSettingPage> {
  final _gatherController = TextEditingController(text: "5");
  final _packController = TextEditingController(text: "30");

  final List<bool> _locationModelSelectedList = [false, false, true];
  final List<bool> _saveSelectedList = [true, false];

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: BMFAppBar(
        title: "追踪设置",
      ),
      body: ListView(
        children: [
          _intervalSection(),
          // _locationModelSection(),  // android独有 先不加
          // _saveSection(), // android独有 先不加
          _footerSection(),
        ],
      ),
    );
  }

  ///
  void _onTapLocationModeBox(int idx) {
    for (int i = 0; i < _locationModelSelectedList.length; i++) {
      _locationModelSelectedList[i] = i == idx;
    }

    setState(() {});
  }

  ///
  void _onTapSaveBox(int idx) {
    for (int i = 0; i < _saveSelectedList.length; i++) {
      _saveSelectedList[i] = i == idx;
    }

    setState(() {});
  }

  ///
  void _onPressedFooter(int idx) async {
    if (idx == 1) {
      /// 设置采集周期和打包上传的周期
      bool flag = await TraceController.shareInstance.setInterval(
        gatherInterval: int.parse(_gatherController.text.isEmpty ? "5" : _gatherController.text),
        packInterval: int.parse(_packController.text.isEmpty ? "30" : _packController.text),
        traceCallback: TraceCallback(
            onSetIntervalCallBack: (SetIntervalErrorCode setIntervalErrorCode) {
          /// TODO: 没回调
          print('--设置采集周期和打包上传周期回调 result = ${setIntervalErrorCode.index}');
        }),
      );
      print('--设置采集周期和打包上传周期 flag = $flag');

      /// 定位模式

    }
    Navigator.pop(context);
  }

  /// 采集、打包频率
  Widget _intervalSection() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(left: 15, top: 10, right: 15),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "采集、打包频率（单位：秒）：",
            style: settingTitleStyle,
          ),
          Row(
            children: [
              Expanded(
                child: BMFTextField(
                  controller: _gatherController,
                  title: "采集频率：",
                ),
              ),
              SizedBox(
                width: 10,
              ),
              Expanded(
                child: BMFTextField(
                  controller: _packController,
                  title: "打包频率：",
                ),
              ),
            ],
          ),
          Container(
            color: separateColor,
            height: 0.5,
            margin: EdgeInsets.only(top: 10),
          ),
        ],
      ),
    );
  }

  /// 定位模式
  Widget _locationModelSection() {
    return Container(
      padding: EdgeInsets.only(left: 15, top: 10, right: 15),
      color: Colors.white,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "定位模式",
            style: settingTitleStyle,
          ),
          SizedBox(
            height: 10,
          ),
          SelectedBox(
            title: "仅使用设备（GPS）定位",
            selected: _locationModelSelectedList[0],
            onTap: () => _onTapLocationModeBox(0),
          ),
          SizedBox(
            height: 10,
          ),
          SelectedBox(
            title: "低功耗定位模式，仅使用网络定位",
            selected: _locationModelSelectedList[1],
            onTap: () => _onTapLocationModeBox(1),
          ),
          SizedBox(
            height: 10,
          ),
          SelectedBox(
            title: "高精度定位模式，GPS与网络综合定位",
            selected: _locationModelSelectedList[2],
            onTap: () => _onTapLocationModeBox(2),
          ),
          Container(
            color: separateColor,
            height: 0.5,
            margin: EdgeInsets.only(top: 10),
          ),
        ],
      ),
    );
  }

  /// 对象存储
  Widget _saveSection() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(left: 15, top: 10, right: 15),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "对象存储",
            style: settingTitleStyle,
          ),
          SizedBox(height: 10),
          Row(
            children: [
              SelectedBox(
                title: "关闭",
                selected: _saveSelectedList[0],
                onTap: () => _onTapSaveBox(0),
              ),
              SizedBox(
                width: 50,
              ),
              SelectedBox(
                title: "开启",
                selected: _saveSelectedList[1],
                onTap: () => _onTapSaveBox(1),
              ),
            ],
          ),
          Container(
            color: separateColor,
            height: 0.5,
            margin: EdgeInsets.only(top: 10),
          ),
        ],
      ),
    );
  }

  /// 取消 确定
  Widget _footerSection() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.all(15),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          BMFRaisedButton(
            title: "取消",
            onPressed: (bool selected) => _onPressedFooter(0),
          ),
          BMFRaisedButton(
            title: "确定",
            onPressed: (bool selected) => _onPressedFooter(1),
          ),
        ],
      ),
    );
  }
}
